;+
; NAME: COMPUTE_CIB
;
; PURPOSE: Compute the CIB from Bethermin et al. (2010) savesets
;
; CALLING SEQUENCE: compute_cib, lambda_sel, cibmed, cibsup, cibinf
;[, zmin = zmin, zmax = zmax, Scut = Scut][, /cold, /sb, /lensed, /non_lensed]
;
; INPUTS:
;        LAMBDA_SEL: working wavelength (this wavelength must
;        correspond to a wavelength in the IDL savesets). 
;
; KEYWORD PARAMETERS:
;                    ZMIN: minimal redshift used to compute the counts.      
;                    ZMAX: maximal ************************************
;                    SCUT: return the contribution of the S>Scut sources
;                    COLD: use only normal/cold populations
;                    SB:   ******** starburst *************
;                    LENSED: use only strongly-lensed sources (mu>2)
;                    UNLENSED: ****** non-lensed sources
;
; OUTPUTS:
;         cibmed: vector of the median counts nW/m2/sr
;         cibsup: ************* 1 sigma sup **************
;         cibinf: ************* 1 sigma inf **************
;
; MODIFICATION HISTORY:
; Written by Matthieu Bethermin in Sept 2010.
; Bug corrected on Scut by Matthieu Bethermin in January 2011.
;-

PRO compute_cib, lambda_sel, cibmed, cibsup, cibinf, zmin = zmin, zmax = zmax, Scut = Scut, cold = cold, sb = sb, lensed = lensed, non_lensed = non_lensed, cib = cib

if keyword_set(lensed) and keyword_set(non_lensed) then begin
   print, 'LENSED and NON_LENSED KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(cold) and keyword_set(sb) then begin
   print, 'COLD AND SB KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(lensed) then restore, 'dndsnudz_arr_lensed_final.save'
if keyword_set(non_lensed) then restore, 'dndsnudz_arr_unlensed_final.save'

if keyword_set(non_lensed) ne 1 and keyword_set(lensed) ne 1 then restore, 'dndsnudz_arr_final.save'

if keyword_set(zmin) ne 1 then zmin = -1.
if keyword_set(zmax) ne 1 then zmax = 1000.

if keyword_set(Scut) ne 1 then Scut = 1.e-10

sellambda = where(abs(lambda-lambda_sel) lt 1.)
sellambda = sellambda(0)

dSnudz = transpose(deriv(z)) ## deriv(Snu)
z_arr = transpose(z) ## (0.*Snu+1.)
Snu_arr = transpose(1.+0.*z) ## Snu

cib_arr = fltarr(Npts)

for k = 0, Npts-1 do begin

   if keyword_set(cold) ne 1 and keyword_set(sb) ne 1 then prop = 1.+0.*dSnudz
   if keyword_set(cold) then prop = propcold_arr(*,*,sellambda,k)
   if keyword_set(sb) then prop = 1.-propcold_arr(*,*,sellambda,k)

   zbad = where(z_arr lt zmin or z_arr gt zmax or Snu_arr le Scut)
   if zbad(0) ne -1 then prop(zbad) = 0.

   cib_arr(k) = 1.e-6*total(prop*dNdSnudz_arr(*,*,sellambda,k)*dSnudz*Snu_arr,/nan)*3000./float(lambda_sel)
endfor

  sup1s = round(0.841345*Npts-0.5)
  inf1s = round(0.158655*Npts-0.5)

  cibmed = fltarr(n_elements(Snu))
  cibsup = fltarr(n_elements(Snu))
  cibinf = fltarr(n_elements(Snu))

  cibmed = median(cib_arr)
  isort = sort(cib_arr)
  cibsup = cib_arr(isort(sup1s))
  cibinf = cib_arr(isort(inf1s))

END
