;+
; NAME: COMPUTE_COUNTS
;
; PURPOSE: Compute the number counts from Bethermin et al. (2010) savesets
;
; CALLING SEQUENCE: compute_counts, lambda_sel, S, dndSmed, dndSsup,
; dndSinf[, zmin = zmin, zmax = zmax][, /cold, /sb, /lensed, /non_lensed]
;
; INPUTS:
;        LAMBDA_SEL: working wavelength (this wavelength must
;        correspond to a wavelength in the IDL savesets). 
;
; KEYWORD PARAMETERS:
;                    ZMIN: minimal redshift used to compute the counts.      
;                    ZMAX: maximal ************************************
;                    COLD: use only normal/cold populations
;                    SB:   ******** starburst *************
;                    LENSED: use only strongly-lensed sources (mu>2)
;                    UNLENSED: ****** non-lensed sources
;
; OUTPUTS:
;         S: vector of fluxes in Jy
;         dNdSmed: vector of the median counts in gal/Jy/sr
;         dNdSsup: ************* 1 sigma sup **************
;         dNdSinf: ************* 1 sigma inf **************
; WARNING:
;         Due to the resolution in redshift of the grid, the very bright
;         counts (>1Jy) can be non euclidian. This is NOT a physical effect.
;  
; MODIFICATION HISTORY:
; Written by Matthieu Bethermin in Sept 2010.
;
;-

PRO compute_counts, lambda_sel, S, dndSmed, dndSsup, dndSinf, zmin = zmin, zmax = zmax, cold = cold, sb = sb, lensed = lensed, non_lensed = non_lensed, cib = cib

if keyword_set(lensed) and keyword_set(non_lensed) then begin
   print, 'LENSED and NON_LENSED KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(cold) and keyword_set(sb) then begin
   print, 'COLD AND SB KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(lensed) then restore, 'dndsnudz_arr_lensed_final.save'
if keyword_set(non_lensed) then restore, 'dndsnudz_arr_unlensed_final.save'

if keyword_set(non_lensed) ne 1 and keyword_set(lensed) ne 1 then restore, 'dndsnudz_arr_final.save'

if keyword_set(zmin) ne 1 then zmin = -1.
if keyword_set(zmax) ne 1 then zmax = 1000.

sellambda = where(abs(lambda-lambda_sel) lt 1.)
sellambda = sellambda(0)

dz = transpose(deriv(z)) ## (0.*Snu+1.)
z_arr = transpose(z) ## (0.*Snu+1.)
S = Snu 

dNdS_arr = fltarr(n_elements(Snu),Npts)

for k = 0, Npts-1 do begin

   if keyword_set(cold) ne 1 and keyword_set(sb) ne 1 then prop = 1.+0.*dz
   if keyword_set(cold) then prop = propcold_arr(*,*,sellambda,k)
   if keyword_set(sb) then prop = 1.-propcold_arr(*,*,sellambda,k)

   zbad = where(z_arr lt zmin or z_arr gt zmax)
   if zbad(0) ne -1 then prop(zbad) = 0.

   dNdS_arr(*,k) = total(prop*dNdSnudz_arr(*,*,sellambda,k)*dz,2,/nan)
endfor

  sup1s = round(0.841345*Npts-0.5)
  inf1s = round(0.158655*Npts-0.5)

  dNdSmed = fltarr(n_elements(Snu))
  dNdSsup = fltarr(n_elements(Snu))
  dNdSinf = fltarr(n_elements(Snu))

  for j = 0, n_elements(Snu)-1 do begin
     dNdSmed(j) = median(dNdS_arr(j,*))
     isort = sort(dNdS_arr(j,*))
     dNdSsup(j) = dNdS_arr(j,isort(sup1s))
     dNdSinf(j) = dNdS_arr(j,isort(inf1s))
  endfor

END
