;+
; NAME: COMPUTE_NZ
;
; PURPOSE: Compute the redshift distribution N(z) from Bethermin et al. (2010) savesets
;
; CALLING SEQUENCE: compute_nz, lambda_sel, Scut, z, Nzmed, Nzsup,
; Nzinf [, /cold, /sb, /lensed, /non_lensed]
;
; INPUTS:
;        LAMBDA_SEL: working wavelength (this wavelength must
;        correspond to a wavelength in the IDL savesets). 
;        SCUT: Flux cut in Jy
;
; KEYWORD PARAMETERS:
;                    COLD: use only normal/cold populations
;                    SB:   ******** starburst *************
;                    LENSED: use only strongly-lensed sources (mu>2)
;                    UNLENSED: ****** non-lensed sources
;
; OUTPUTS:
;         z: vector of redshift
;         Nzmed: vector of the median counts in gal/sr (dN/dz/dOmega)
;         Nzsup: ************* 1 sigma sup **************
;         Nzinf: ************* 1 sigma inf **************
;
; MODIFICATION HISTORY:
; Written by Matthieu Bethermin in Sept 2010.
;-

PRO compute_nz, lambda_sel, Scut, z, Nzmed, Nzsup, Nzinf, cold=cold, sb=sb, lensed=lensed, non_lensed=non_lensed

if keyword_set(lensed) and keyword_set(non_lensed) then begin
   print, 'LENSED and NON_LENSED KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(cold) and keyword_set(sb) then begin
   print, 'COLD AND SB KEYWORDS CANNOT BE SIMULTANEOUSLY USED'
endif

if keyword_set(lensed) then restore, 'dndsnudz_arr_lensed_final.save'
if keyword_set(non_lensed) then restore, 'dndsnudz_arr_unlensed_final.save'

if keyword_set(non_lensed) ne 1 and keyword_set(lensed) ne 1 then restore, 'dndsnudz_arr_final.save'


sellambda = where(abs(lambda-lambda_sel) lt 1.)
sellambda = sellambda(0)

dSnu = transpose(1.+0.*z) ## deriv(Snu)
S = Snu 
Snu_arr = transpose(1.+0.*z) ## Snu

Nz_arr = fltarr(n_elements(z),Npts)

S_i = Scut*10.^(0.001*findgen(4000))
dS_i = deriv(S_i)

for k = 0, Npts-1 do begin

   if keyword_set(cold) ne 1 and keyword_set(sb) ne 1 then prop = 1.+0.*dSnu
   if keyword_set(cold) then prop = propcold_arr(*,*,sellambda,k)
   if keyword_set(sb) then prop = 1.-propcold_arr(*,*,sellambda,k)

   mask = 1.+0.*Snu_arr
   good = where(Snu_arr gt Scut)
   mask(good) = 1.

   for j = 0, n_elements(z)-1 do begin
      dndSnudz_i = exp(interpol(alog(dNdSnudz_arr(*,j,sellambda,k)),alog(Snu),alog(S_i)))

      Nz_arr(j,k) = total(mask(*,j)*prop(*,j)*dS_i*dNdSnudz_i,/nan) ;FIRST APPROXIMATION
   endfor

endfor

sup1s = round(0.841345*Npts-0.5)
inf1s = round(0.158655*Npts-0.5)

Nzmed = fltarr(n_elements(z))
Nzsup = fltarr(n_elements(z))
Nzinf = fltarr(n_elements(z))

for j = 0, n_elements(z)-1 do begin
   Nzmed(j) = median(Nz_arr(j,*))
   isort = sort(Nz_arr(j,*))
   Nzsup(j) = Nz_arr(j,isort(sup1s))
   Nzinf(j) = Nz_arr(j,isort(inf1s))
endfor

END
